SVGDocument class

Constructors

SVGDocument({bool addHeader = false, bool edgeOnly = false})

Properties

attributes ↔ Map<String, String>
getter/setter pair
childNodes ↔ List<Map<String, String>>
getter/setter pair
edgeOnly ↔ bool
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
style ↔ Map<String, String>
getter/setter pair
styleNodes ↔ List<Map<String, String>>
getter/setter pair

Methods

appendChild(SVGDocument document) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeChild(Map<String, String> node) → void
setAttribute(String attribute, String info) → void
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited