SVGLoaderParser class

Constructors

SVGLoaderParser(String text, {num defaultDPI = 90, SVGUnits defaultUnit = SVGUnits.px})
SVGLoaderParser.parser()

Properties

currentTransform → Matrix3
final
defaultDPI ↔ num
getter/setter pair
defaultUnit ↔ SVGUnits
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
paths ↔ List<ShapePath>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stylesheets ↔ Map
getter/setter pair
tempTransform0 → Matrix3
final
tempTransform1 → Matrix3
final
tempTransform2 → Matrix3
final
tempTransform3 → Matrix3
final
tempV2 → Vector2
final
tempV3 → Vector3
final
transformStack → List
final
unitConversion → Map<String, dynamic>
final
units → List<String>
final
xml ↔ XmlDocument
latefinal

Methods

getNodeTransform(XmlElement node) → Matrix3?
getReflection(double a, double b) → double
getTransformScaleX(Matrix3 m) → double
getTransformScaleY(Matrix3 m) → double
isTransformRotated(Matrix3 m) → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parse(String text) → SVGData
parseArcCommand(ShapePath path, double rx, double ry, double xAxisRotation, double largeArcFlag, double sweepFlag, Vector start, Vector end) → void
  • https://www.w3.org/TR/SVG/implnote.html#ArcImplementationNotes
  • parseCircleNode(XmlElement node) → ShapePath
    parseCSSStylesheet(XmlElement node) → void
    parseEllipseNode(XmlElement node) → ShapePath
    parseFloats(String input, [List? flags, int stride = 1]) → List<double>
    parseFloatWithUnits([String? string]) → double
    parseLineNode(XmlElement node) → ShapePath
    parseNode(dynamic node, dynamic style) → void
    parseNodeTransform(XmlElement node) → Matrix3
    parsePath(String d) → ShapePath
    parsePathNode(XmlElement node) → ShapePath
    parsePolygonNode(XmlElement node) → ShapePath
    parsePolylineNode(XmlElement node) → ShapePath
    parseRectNode(XmlElement node) → ShapePath
    parseStyle(XmlElement node, Map<String, dynamic> style) → Map<String, dynamic>
    substr(String str, int start, [int? length]) → String
    svgAngle(double ux, double uy, double vx, double vy) → double
    toString() → String
    A string representation of this object.
    inherited
    transformPath(dynamic path, Matrix3 m) → void

    Operators

    operator ==(Object other) → bool
    The equality operator.
    inherited

    Static Methods

    getStrokeStyle([double width = 1, String color = '#000', String lineJoin = 'miter', String lineCap = 'butt', double miterLimit = 4]) → Map<String, dynamic>